mod util;

mod core {
    mod test_eventlog;
    mod test_gc;
    mod test_hooks;
}

mod command {
    mod test_amend;
    mod test_hide;
    mod test_init;
    mod test_move;
    mod test_navigation;
    mod test_restack;
    mod test_smartlog;
    mod test_undo;
    mod test_wrap;
}
